# Loader

::: cryowire.loader

## Functions

| Function | Description |
| --- | --- |
| `load_cooldown(path)` | Load a cooldown directory, returns `(metadata, control, rs, rr)` |
| `load_yaml(path)` | Load a YAML file |
| `load_components(path)` | Load component catalog |
| `default_components_path()` | Path to bundled component catalog |
| `templates_dir()` | Path to bundled templates directory |
